# Table of Contents

- [modeling-sap-interfaces-and-external-partners](<./modeling-sap-interfaces-and-external-partners.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling SAP Interfaces and External Partners](<./Modeling-SAP-Interfaces-and-External-Partners.md>)
  - [Was this page helpful?](<./Modeling-SAP-Interfaces-and-External-Partners/Was-this-page-helpful.md>)
